diff src/protocols/msn/switchboard.h @ 8583:fc27237783ee

[gaim-migrate @ 9333] Added Felipe Contreras's patch to reorganize and clean up the MSN protocol plugin. Thanks, and once again, apologies for the what must have seemed a never-ending delay. committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Mon, 05 Apr 2004 07:11:24 +0000
parents 06f57183e29f
children bbd8cdaf0ad5
line wrap: on
line diff
--- a/src/protocols/msn/switchboard.h	Mon Apr 05 06:52:02 2004 +0000
+++ b/src/protocols/msn/switchboard.h	Mon Apr 05 07:11:24 2004 +0000
@@ -40,6 +40,7 @@
 	char *session_id;
 
 	gboolean invited;
+	gboolean destroying;
 
 	GaimConversation *chat;
 
@@ -146,13 +147,13 @@
  * Connects to a switchboard.
  *
  * @param swboard The switchboard.
  * @param server  The server.
  * @param port    The port.
  *
  * @return @c TRUE if able to connect, or @c FALSE otherwise.
  */
 gboolean msn_switchboard_connect(MsnSwitchBoard *swboard,
-								 const char *server, int port);
+								 const char *host, int port);
 
 /**
  * Disconnects from a switchboard.
@@ -146,13 +147,13 @@
  *
  * @param swboard The switchboard.
- * @param server  The server.
+ * @param host    The host.
  * @param port    The port.
  *